@@ -19,7 +19,7 @@ use Lucy::Index::Indexer;
 use Try::Tiny;
 use Archive::Zip qw(AZ_OK);
 use namespace::autoclean;
-our $VERSION = v0.16.3;
+our $VERSION = v0.16.4;
 
 has verbose  => (is => 'rw', isa => 'Int', default => 0);
 has to_index => (is => 'ro', isa => 'HashRef', default => sub { +{
@@ -365,6 +365,7 @@ sub update_extensions {
 
     while (my ($ext, $data) = each %{ $meta->{provides} }) {
         say "    $ext" if $self->verbose > 1;
+        $ext = lc $ext;
         # Read in extension metadata from the mirror.
         my $mir_file = $self->mirror_file_for(
             extension => $meta,
@@ -914,6 +915,7 @@ sub _clean_html_body {
 
     my %gen_ids;
     my $level = 1;
+    my $pgxnbod;
 
     while ($elem) {
         if ($elem->nodeType == XML_ELEMENT_NODE) {
@@ -925,14 +927,17 @@ sub _clean_html_body {
                 } $elem->attributes;
                 $elem->setNodeName('div');
                 $elem->setAttribute(id => 'pgxnbod');
+                $pgxnbod = $elem;
                 $elem = $elem->firstChild || last;
                 next;
             }
 
             if (my $attrs = $allowed{$name}) {
                 # Keep only allowed attributes.
-                $elem->removeAttribute($_) for grep { !$attrs->{$_} }
-                    map { $_->nodeName } $elem->attributes;
+                if (!$pgxnbod || !$elem->isSameNode($pgxnbod)) {
+                    $elem->removeAttribute($_) for grep { !$attrs->{$_} }
+                        map { $_->nodeName } $elem->attributes;
+                }
 
                 if ($name =~ /^h([123])$/) {
                     my $header = $1;
@@ -996,7 +1001,7 @@ sub _clean_html_body {
 
                     # No sibling, try parent's sibling
                     $next = $next->parentNode;
-                    redo if $next && $next ne $top;
+                    redo if $next && !$next->isSameNode($top);
                 }
                 $parent->removeChild($elem);
                 $elem = $next;
